==> xlniuxdata-jinzuan-1.0.4-20141021.062936-1-sources.jar: com/xunlei/niux/data/jinzuan/vo/PrivilegeReceiveInfo.java <==
package com.xunlei.niux.data.jinzuan.vo;



import com.ferret.common.dao.annotation.Table;



/**
 * 金钻特权领取
 * @author lisu
 * 2014-03-03
 */
@Table(tableName="jinzuan_privilegereceiveinfo",pkFieldName="seqId",pkFieldAssign=false)
public class PrivilegeReceiveInfo {
	private Long seqId;
    private Long userId;
    private Integer privilegeType;
    private Long totalValue;
    private Long availableValue;
    private String yearMonth;
    private String recordTime;
    private String simpleName;
    private Boolean isvalid;
    
    
    
    
	public Boolean getIsvalid() {
		return isvalid;
	}
	public void setIsvalid(Boolean isvalid) {
		this.isvalid = isvalid;
	}
	public String getSimpleName() {
		return simpleName;
	}
	public void setSimpleName(String simpleName) {
		this.simpleName = simpleName;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public Integer getPrivilegeType() {
		return privilegeType;
	}
	public void setPrivilegeType(Integer privilegeType) {
		this.privilegeType = privilegeType;
	}
	public Long getTotalValue() {
		return totalValue;
	}
	public void setTotalValue(Long totalValue) {
		this.totalValue = totalValue;
	}
	public Long getAvailableValue() {
		return availableValue;
	}
	public void setAvailableValue(Long availableValue) {
		this.availableValue = availableValue;
	}
	public String getYearMonth() {
		return yearMonth;
	}
	public void setYearMonth(String yearMonth) {
		this.yearMonth = yearMonth;
	}
	public String getRecordTime() {
		return recordTime;
	}
	public void setRecordTime(String recordTime) {
		this.recordTime = recordTime;
	}

}

==> xlniuxdata-jinzuan-1.0.7-20161014.034359-11-sources.jar: com/xunlei/niux/data/jinzuan/vo/PrivilegeReceiveInfo.java <==
package com.xunlei.niux.data.jinzuan.vo;



import com.ferret.common.dao.annotation.Table;



/**
 * 金钻特权领取
 * @author lisu
 * 2014-03-03
 */
@Table(tableName="jinzuan_privilegereceiveinfo",pkFieldName="seqId",pkFieldAssign=false)
public class PrivilegeReceiveInfo {
	private Long seqId;
    private Long userId;
    private Integer privilegeType;
    private Long totalValue;
    private Long availableValue;
    private String yearMonth;
    private String recordTime;
    private String simpleName;
    private Boolean isvalid;
    
	public Boolean getIsvalid() {
		return isvalid;
	}
	public void setIsvalid(Boolean isvalid) {
		this.isvalid = isvalid;
	}
	public String getSimpleName() {
		return simpleName;
	}
	public void setSimpleName(String simpleName) {
		this.simpleName = simpleName;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public Integer getPrivilegeType() {
		return privilegeType;
	}
	public void setPrivilegeType(Integer privilegeType) {
		this.privilegeType = privilegeType;
	}
	public Long getTotalValue() {
		return totalValue;
	}
	public void setTotalValue(Long totalValue) {
		this.totalValue = totalValue;
	}
	public Long getAvailableValue() {
		return availableValue;
	}
	public void setAvailableValue(Long availableValue) {
		this.availableValue = availableValue;
	}
	public String getYearMonth() {
		return yearMonth;
	}
	public void setYearMonth(String yearMonth) {
		this.yearMonth = yearMonth;
	}
	public String getRecordTime() {
		return recordTime;
	}
	public void setRecordTime(String recordTime) {
		this.recordTime = recordTime;
	}
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("[seqId=").append(seqId)
				.append(", userId=").append(userId).append(", privilegeType=")
				.append(privilegeType).append(", totalValue=")
				.append(totalValue).append(", availableValue=")
				.append(availableValue).append(", yearMonth=")
				.append(yearMonth).append(", recordTime=").append(recordTime)
				.append(", simpleName=").append(simpleName)
				.append(", isvalid=").append(isvalid).append("]");
		return builder.toString();
	}
	
}
